@@ -159,19 +159,19 @@ outro_message(struct notcurses* nc, int* rows, int* cols){
   if(ncplane_set_bg_alpha(non, CELL_ALPHA_BLEND)){
     return NULL;
   }
-  ncplane_styles_on(non, NCSTYLE_BOLD);
+  ncplane_on_styles(non, NCSTYLE_BOLD);
   if(ncplane_putstr_aligned(non, ++ybase, NCALIGN_CENTER, str0) < 0){
     return NULL;
   }
-  ncplane_styles_off(non, NCSTYLE_BOLD);
+  ncplane_off_styles(non, NCSTYLE_BOLD);
   if(ncplane_putstr_aligned(non, ++ybase, NCALIGN_CENTER, str1) < 0){
     return NULL;
   }
-  ncplane_styles_on(non, NCSTYLE_ITALIC);
+  ncplane_on_styles(non, NCSTYLE_ITALIC);
   if(ncplane_putstr_aligned(non, ++ybase, NCALIGN_CENTER, str2) < 0){
     return NULL;
   }
-  ncplane_styles_off(non, NCSTYLE_ITALIC);
+  ncplane_off_styles(non, NCSTYLE_ITALIC);
   *rows = ystart;
   *cols = xs;
   return non;
