@@ -75,11 +75,6 @@ draw_block(struct ncplane* nn, uint32_t blockstart){
         if(wcwidth(w) < 2){
           utf8arr[bwc++] = ' ';
         }
-        if(uc_bidi_category(w)){
-          utf8arr[bwc++] = 0xe2;
-          utf8arr[bwc++] = 0x80;
-          utf8arr[bwc++] = 0x8e;
-        }
         utf8arr[bwc++] = '\0';
       }else{ // don't dump non-printing codepoints
         strcpy(utf8arr, "  ");
