@@ -199,10 +199,10 @@ message(struct ncplane* n, int maxy, int maxx, int num, int total,
   ncplane_putegc_yx(n, 2, 19, "╨", NULL);
   ncplane_set_fg_rgb8(n, 64, 128, 240);
   ncplane_set_bg_rgb8(n, 32, 64, 32);
-  ncplane_styles_on(n, NCSTYLE_ITALIC);
+  ncplane_on_styles(n, NCSTYLE_ITALIC);
   ncplane_printf_yx(n, 5, 18, " bytes: %05d EGCs: %05d cols: %05d ", bytes_out, egs_out, cols_out);
   ncplane_printf_yx(n, 1, 4, " %03dx%03d (%d/%d) ", maxx, maxy, num + 1, total);
-  ncplane_styles_off(n, NCSTYLE_ITALIC);
+  ncplane_off_styles(n, NCSTYLE_ITALIC);
   ncplane_set_fg_rgb8(n, 224, 128, 224);
   ncplane_putstr_yx(n, 3, 1, "   🔥 unicode 13, resize awareness, 24b truecolor…🔥   ");
   ncplane_set_fg_rgb8(n, 255, 255, 255);
@@ -289,8 +289,6 @@ int witherworm_demo(struct notcurses* nc){
     "ብርሃነ ዘርኣይ",
     "ኃይሌ ገብረሥላሴ",
     "ᓱᒻᒪᓂᒃᑯᐊ ᐃᓄᑦᑎᑐᑐᐃᓐᓇᔭᙱᓚᑦ",
-    "∮ E⋅da = Q,  n → ∞, ∑ f(i) = ∏ g(i), ∀x∈ℝ: ⌈x⌉ = −⌊−x⌋, α ∧ ¬β = ¬(¬α ∨ β)"
-    "2H₂ + O₂ ⇌ 2H₂O, R = 4.7 kΩ, ⌀ 200mm",
     "ði ıntəˈnæʃənəl fəˈnɛtık əsoʊsiˈeıʃn",
     "((V⍳V)=⍳⍴V)/V←,V    ⌷←⍳→⍴∆∇⊃‾⍎⍕⌈",
     "Eڿᛯℇ✈ಅΐʐ𝍇Щঅ℻ ⌬⌨ ⌣₰ ⠝ ‱ ‽ ח ֆ ∜ ⨀ ĲႪ ⇠ ਐ ῼ இ ╁ ଠ ୭ ⅙ ㈣⧒ ₔ ⅷ ﭗ ゛〃・ ↂ ﻩ ✞ ℼ ⌧",
@@ -501,10 +499,6 @@ int witherworm_demo(struct notcurses* nc){
             idx += eaten;
             continue;
           }
-          if(uc_bidi_category(wcs)){ // FIXME
-            idx += eaten;
-            continue;
-          }
           int ulen = 0;
           int r;
           if(wcwidth(wcs) <= maxx - x){
@@ -583,6 +577,7 @@ int witherworm_demo(struct notcurses* nc){
         DEMO_RENDER(nc);
       }
     }while(key == NCKEY_RESIZE);
+    notcurses_refresh(nc, NULL, NULL);
   }
   ncplane_set_scrolling(n, false);
   return 0;
