@@ -252,6 +252,7 @@ typedef struct tinfo {
   char* getm;     // get mouse events
   bool RGBflag;   // ti-reported "RGB" flag for 24bpc truecolor
   bool CCCflag;   // ti-reported "CCC" flag for palette set capability
+  bool BCEflag;   // ti-reported "BCE" flag for erases with background color
   bool AMflag;    // ti-reported "AM" flag for automatic movement to next line
   char* smcup;    // enter alternate mode
   char* rmcup;    // restore primary mode
@@ -289,6 +290,7 @@ typedef struct ncdirect {
   // typical order. we detect it the first time ncdirect_cursor_yx() is called.
   bool detected_cursor_inversion; // have we performed inversion testing?
   bool inverted_cursor;      // does the terminal return inverted coordinates?
+  uint64_t flags;            // copied in ncdirect_init() from param
 } ncdirect;
 
 typedef struct notcurses {
@@ -310,7 +312,7 @@ typedef struct notcurses {
   int cursorx;    //  care, otherwise moved here after each render.
 
   ncstats stats;  // some statistics across the lifetime of the notcurses ctx
-  ncstats stashstats; // cumulative stats, unaffected by notcurses_reset_stats()
+  ncstats stashstats; // cumulative stats, unaffected by notcurses_stats_reset()
 
   int truecols;   // true number of columns in the physical rendering area.
                   // used only to see if output motion takes us to the next
@@ -898,6 +900,31 @@ cell_blend_bchannel(cell* cl, unsigned channel, unsigned* blends){
   return cell_set_bchannel(cl, channels_blend(cell_bchannel(cl), channel, blends));
 }
 
+// examine the UTF-8 EGC in the first |*bytes| bytes of |egc|. if the EGC is
+// right-to-left, we make a copy, appending an U+200E to force left-to-right.
+// only the first unicode char of the EGC is currently checked FIXME. if the
+// EGC is not RTL, we return NULL.
+static char*
+egc_rtl(const char* egc, int* bytes){
+  wchar_t w;
+  mbstate_t mbstate = { };
+  size_t r = mbrtowc(&w, egc, *bytes, &mbstate);
+  if(r == (size_t)-1 || r == (size_t)-2){
+    return NULL;
+  }
+  const int bidic = uc_bidi_category(w);
+  if(bidic != UC_BIDI_R && bidic != UC_BIDI_RLE && bidic != UC_BIDI_RLO){
+    return NULL;
+  }
+  // insert U+200E, "LEFT-TO-RIGHT MARK". This ought reset the text direction
+  // after emitting a potentially RTL EGC.
+  const char LTRMARK[] = "\xe2\x80\x8e";
+  char* s = (char*)malloc(*bytes + sizeof(LTRMARK)); // cast for C++ callers
+  memcpy(s, egc, *bytes);
+  memcpy(s + *bytes, LTRMARK, sizeof(LTRMARK));
+  return s;
+}
+
 static inline int
 pool_load_direct(egcpool* pool, cell* c, const char* gcluster, int bytes, int cols){
   if(bytes < 0 || cols < 0){
@@ -923,15 +950,26 @@ pool_load_direct(egcpool* pool, cell* c, const char* gcluster, int bytes, int co
     c->channels |= CELL_NOBACKGROUND_MASK;
     c->channels &= ~CELL_WIDEASIAN_MASK;
   }
+  // checks for RTL and adds U+200E if so FIXME
+  char* rtl = egc_rtl(gcluster, &bytes);
+  if(rtl){
+    gcluster = rtl;
+  }
   if(bytes <= 4){
     if(strcmp(gcluster, (const char*)&c->gcluster)){
       pool_release(pool, c);
       c->gcluster = 0;
       memcpy(&c->gcluster, gcluster, bytes);
     }
+    if(rtl){
+      free(rtl);
+    }
     return bytes;
   }
   int eoffset = egcpool_stash(pool, gcluster, bytes);
+  if(rtl){
+    free(rtl);
+  }
   if(eoffset < 0){
     return -1;
   }
@@ -989,7 +1027,7 @@ cellcmp_and_dupfar(egcpool* dampool, cell* damcell,
 int ncinputlayer_init(ncinputlayer* nilayer, FILE* infp);
 
 // FIXME absorb into ncinputlayer_init()
-int cbreak_mode(int ttyfd, struct termios* tpreserved);
+int cbreak_mode(int ttyfd, const struct termios* tpreserved);
 
 #ifdef __cplusplus
 }
