@@ -237,7 +237,7 @@ write_header(ncmenu* ncm){ ncm->ncp->channels = ncm->headerchannels;
     return -1;
   }
   cell c = CELL_INITIALIZER(' ', 0, ncm->headerchannels);
-  ncplane_set_attr(ncm->ncp, 0);
+  ncplane_set_styles(ncm->ncp, 0);
   if(ncplane_putc(ncm->ncp, &c) < 0){
     return -1;
   }
@@ -268,7 +268,7 @@ write_header(ncmenu* ncm){ ncm->ncp->channels = ncm->headerchannels;
         if(ncplane_at_yx_cell(ncm->ncp, ypos, xoff + ncm->sections[i].shortcut_offset, &cl) < 0){
           return -1;
         }
-        cell_styles_on(&cl, NCSTYLE_UNDERLINE|NCSTYLE_BOLD);
+        cell_on_styles(&cl, NCSTYLE_UNDERLINE|NCSTYLE_BOLD);
         if(ncplane_putc_yx(ncm->ncp, ypos, xoff + ncm->sections[i].shortcut_offset, &cl) < 0){
           return -1;
         }
@@ -377,9 +377,9 @@ int ncmenu_unroll(ncmenu* n, int sectionidx){
     if(sec->items[i].desc){
       n->ncp->channels = n->sectionchannels;
       if(i == sec->itemselected){
-        ncplane_set_attr(n->ncp, NCSTYLE_REVERSE);
+        ncplane_set_styles(n->ncp, NCSTYLE_REVERSE);
       }else{
-        ncplane_set_attr(n->ncp, 0);
+        ncplane_set_styles(n->ncp, 0);
       }
       int cols = ncplane_putstr_yx(n->ncp, ypos, xpos + 1, sec->items[i].desc);
       if(cols < 0){
@@ -408,7 +408,7 @@ int ncmenu_unroll(ncmenu* n, int sectionidx){
         if(ncplane_at_yx_cell(n->ncp, ypos, xpos + 1 + sec->items[i].shortcut_offset, &cl) < 0){
           return -1;
         }
-        cell_styles_on(&cl, NCSTYLE_UNDERLINE|NCSTYLE_BOLD);
+        cell_on_styles(&cl, NCSTYLE_UNDERLINE|NCSTYLE_BOLD);
         if(ncplane_putc_yx(n->ncp, ypos, xpos + 1 + sec->items[i].shortcut_offset, &cl) < 0){
           return -1;
         }
@@ -416,7 +416,7 @@ int ncmenu_unroll(ncmenu* n, int sectionidx){
       }
     }else{
       n->ncp->channels = n->headerchannels;
-      ncplane_set_attr(n->ncp, 0);
+      ncplane_set_styles(n->ncp, 0);
       if(ncplane_putegc_yx(n->ncp, ypos, xpos, "├", NULL) < 0){
         return -1;
       }
