@@ -380,6 +380,7 @@ create_initial_ncplane(notcurses* nc, int dimy, int dimx){
     },
     .rows = dimy - (nc->margin_t + nc->margin_b),
     .cols = dimx - (nc->margin_l + nc->margin_r),
+    .name = "std",
   };
   return nc->stdplane = ncplane_new_internal(nc, NULL, &nopts);
 }
@@ -396,6 +397,22 @@ ncplane* ncplane_create(ncplane* n, const ncplane_options* nopts){
   return ncplane_new_internal(n->nc, n, nopts);
 }
 
+struct ncplane* ncplane_new(struct ncplane* n, int rows, int cols, int y, int x, void* opaque, const char* name){
+  ncplane_options nopts = {
+    .y = y,
+    .horiz = {
+      .x = x,
+    },
+    .rows = rows,
+    .cols = cols,
+    .userptr = opaque,
+    .name = name,
+    .resizecb = NULL,
+    .flags = 0,
+  };
+  return ncplane_create(n, &nopts);
+}
+
 void ncplane_home(ncplane* n){
   n->x = 0;
   n->y = 0;
@@ -434,7 +451,7 @@ inline int ncplane_cursor_move_yx(ncplane* n, int y, int x){
 ncplane* ncplane_dup(const ncplane* n, void* opaque){
   int dimy = n->leny;
   int dimx = n->lenx;
-  uint16_t attr = ncplane_attr(n);
+  uint16_t attr = ncplane_styles(n);
   uint64_t chan = ncplane_channels(n);
   // if we're duping the standard plane, we need adjust for marginalia
   const struct notcurses* nc = ncplane_notcurses_const(n);
@@ -698,7 +715,11 @@ void notcurses_stats(const notcurses* nc, ncstats* stats){
   memcpy(stats, &nc->stats, sizeof(*stats));
 }
 
-void notcurses_reset_stats(notcurses* nc, ncstats* stats){
+ncstats* notcurses_stats_alloc(const notcurses* nc __attribute__ ((unused))){
+  return malloc(sizeof(ncstats));
+}
+
+void notcurses_stats_reset(notcurses* nc, ncstats* stats){
   if(stats){
     memcpy(stats, &nc->stats, sizeof(*stats));
   }
@@ -830,11 +851,7 @@ get_tty_fd(notcurses* nc, FILE* ttyfp){
   return fd;
 }
 
-int cbreak_mode(int ttyfd, struct termios* tpreserved){
-  if(tcgetattr(ttyfd, tpreserved)){
-    fprintf(stderr, "Couldn't preserve terminal state for %d (%s)\n", ttyfd, strerror(errno));
-    return -1;
-  }
+int cbreak_mode(int ttyfd, const struct termios* tpreserved){
   // assume it's not a true terminal (e.g. we might be redirected to a file)
   struct termios modtermios;
   memcpy(&modtermios, tpreserved, sizeof(modtermios));
@@ -928,8 +945,12 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   }
   ret->ttyfd = get_tty_fd(ret, ret->ttyfp);
   is_linux_console(ret, !!(opts->flags & NCOPTION_NO_FONT_CHANGES));
-  notcurses_mouse_disable(ret);
   if(ret->ttyfd >= 0){
+    if(tcgetattr(ret->ttyfd, &ret->tpreserved)){
+      fprintf(stderr, "Couldn't preserve terminal state for %d (%s)\n", ret->ttyfd, strerror(errno));
+      free(ret);
+      return NULL;
+    }
     if(cbreak_mode(ret->ttyfd, &ret->tpreserved)){
       free(ret);
       return NULL;
@@ -953,6 +974,7 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   }else{
     dimy = 24; // fuck it, lol
     dimx = 80;
+    fprintf(stderr, "Defaulting to %dx%d (output is not to a terminal)\n", dimy, dimx);
   }
   ret->suppress_banner = opts->flags & NCOPTION_SUPPRESS_BANNERS;
   char* shortname_term = termname();
@@ -966,6 +988,7 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
   if(interrogate_terminfo(&ret->tcache)){
     goto err;
   }
+  reset_term_attributes(ret);
   if(ncinputlayer_init(&ret->input, stdin)){
     goto err;
   }
@@ -1007,6 +1030,10 @@ notcurses* notcurses_init(const notcurses_options* opts, FILE* outfp){
         free_plane(ret->top);
         goto err;
       }
+      // explicit clear even though smcup *might* clear
+      if(tty_emit("clear", ret->tcache.clearscr, ret->ttyfd)){
+        notcurses_refresh(ret, NULL, NULL);
+      }
     }else if(!(opts->flags & NCOPTION_NO_ALTERNATE_SCREEN)){
       // if they expected the alternate screen, but we didn't have one to
       // offer, at least clear the screen. try using "clear"; if that doesn't
@@ -1115,11 +1142,7 @@ uint64_t ncplane_channels(const ncplane* n){
   return n->channels;
 }
 
-uint16_t ncplane_attr(const ncplane* n){
-  return n->stylemask;
-}
-
-unsigned ncplane_styles(const ncplane* n){
+uint16_t ncplane_styles(const ncplane* n){
   return n->stylemask;
 }
 
@@ -1500,23 +1523,30 @@ bool notcurses_cantruecolor(const notcurses* nc){
 }
 
 // conform to the specified stylebits
-void ncplane_styles_set(ncplane* n, unsigned stylebits){
+void ncplane_set_styles(ncplane* n, unsigned stylebits){
   n->stylemask = (stylebits & NCSTYLE_MASK);
 }
 
+void ncplane_styles_set(ncplane* n, unsigned stylebits){ // deprecated
+  ncplane_set_styles(n, stylebits);
+}
+
 // turn on any specified stylebits
-void ncplane_styles_on(ncplane* n, unsigned stylebits){
+void ncplane_on_styles(ncplane* n, unsigned stylebits){
   n->stylemask |= (stylebits & NCSTYLE_MASK);
 }
 
+void ncplane_styles_on(ncplane* n, unsigned stylebits){ // deprecated
+  ncplane_on_styles(n, stylebits);
+}
+
 // turn off any specified stylebits
-void ncplane_styles_off(ncplane* n, unsigned stylebits){
+void ncplane_off_styles(ncplane* n, unsigned stylebits){
   n->stylemask &= ~(stylebits & NCSTYLE_MASK);
 }
 
-// set the current stylebits to exactly those provided
-void ncplane_set_attr(ncplane* n, unsigned stylebits){
-  n->stylemask = stylebits & NCSTYLE_MASK;
+void ncplane_styles_off(ncplane* n, unsigned stylebits){ // deprecated
+  ncplane_off_styles(n, stylebits);
 }
 
 // i hate the big allocation and two copies here, but eh what you gonna do?
