@@ -114,7 +114,7 @@ typedef enum {
 //    * draw through edge
 
 static int
-draw_borders(ncplane* w, unsigned mask, uint64_t channel){
+draw_borders(ncplane* w, unsigned mask, uint64_t channel, direction_e direction){
   int lenx, leny;
   int ret = 0;
   ncplane_dim_yx(w, &leny, &lenx);
@@ -129,19 +129,21 @@ draw_borders(ncplane* w, unsigned mask, uint64_t channel){
 //fprintf(stderr, "drawing borders %p ->%d/%d, mask: %04x\n", w, maxx, maxy, mask);
   // lenx is the number of columns we have, but drop 2 due to corners. we thus
   // want lenx horizontal lines.
-  if(!(mask & NCBOXMASK_TOP)){
-    ncplane_home(w);
-    ncplane_putc(w, &ul);
-    ncplane_hline(w, &hl, lenx - 2);
-    ncplane_putc(w, &ur);
-  }else{
-    if(!(mask & NCBOXMASK_LEFT)){
+  if(maxy || direction == DIRECTION_DOWN){
+    if(!(mask & NCBOXMASK_TOP)){
       ncplane_home(w);
       ncplane_putc(w, &ul);
-    }
-    if(!(mask & NCBOXMASK_RIGHT)){
-      ncplane_cursor_move_yx(w, 0, lenx - 1);
+      ncplane_hline(w, &hl, lenx - 2);
       ncplane_putc(w, &ur);
+    }else{
+      if(!(mask & NCBOXMASK_LEFT)){
+        ncplane_home(w);
+        ncplane_putc(w, &ul);
+      }
+      if(!(mask & NCBOXMASK_RIGHT)){
+        ncplane_cursor_move_yx(w, 0, lenx - 1);
+        ncplane_putc(w, &ur);
+      }
     }
   }
   int y;
@@ -155,20 +157,22 @@ draw_borders(ncplane* w, unsigned mask, uint64_t channel){
       ncplane_putc(w, &vl);
     }
   }
-  if(!(mask & NCBOXMASK_BOTTOM)){
-    ret |= ncplane_cursor_move_yx(w, maxy, 0);
-    ncplane_putc(w, &ll);
-    ncplane_hline(w, &hl, lenx - 2);
-    ncplane_putc(w, &lr);
-  }else{
-    if(!(mask & NCBOXMASK_LEFT)){
-      if(ncplane_cursor_move_yx(w, maxy, 0) || ncplane_putc(w, &ll) < 0){
-        ret = -1;
+  if(maxy || direction == DIRECTION_UP){
+    if(!(mask & NCBOXMASK_BOTTOM)){
+      ret |= ncplane_cursor_move_yx(w, maxy, 0);
+      ncplane_putc(w, &ll);
+      ncplane_hline(w, &hl, lenx - 2);
+      ncplane_putc(w, &lr);
+    }else{
+      if(!(mask & NCBOXMASK_LEFT)){
+        if(ncplane_cursor_move_yx(w, maxy, 0) || ncplane_putc(w, &ll) < 0){
+          ret = -1;
+        }
       }
-    }
-    if(!(mask & NCBOXMASK_RIGHT)){
-      if(ncplane_cursor_move_yx(w, maxy, maxx) || ncplane_putc(w, &lr) < 0){
-        ret = -1;
+      if(!(mask & NCBOXMASK_RIGHT)){
+        if(ncplane_cursor_move_yx(w, maxy, maxx) || ncplane_putc(w, &lr) < 0){
+          ret = -1;
+        }
       }
     }
   }
@@ -186,7 +190,8 @@ draw_ncreel_borders(const ncreel* nr){
   assert(maxy >= 0 && maxx >= 0);
   --maxx; // last column we can safely write to
   --maxy; // last line we can safely write to
-  return draw_borders(nr->p, nr->ropts.bordermask, nr->ropts.borderchan);
+  return draw_borders(nr->p, nr->ropts.bordermask, nr->ropts.borderchan,
+                      DIRECTION_UP); // direction shouldn't matter for reel
 }
 
 // Calculate the starting and ending coordinates available for occupation by
@@ -222,6 +227,13 @@ tablet_geom(const ncreel* nr, nctablet* t, int* begx, int* begy,
   if(!(nr->ropts.bordermask & NCBOXMASK_RIGHT)){
     --*lenx;
   }
+  if(!(nr->ropts.bordermask & NCBOXMASK_TOP)){
+    ++*begy;
+    --*leny;
+  }
+  if(!(nr->ropts.bordermask & NCBOXMASK_BOTTOM)){
+    --*leny;
+  }
   // at this point, our coordinates describe the largest possible tablet for
   // this ncreel. this is the correct solution for the focused tablet. other
   // tablets can only grow in one of two directions, so tighten them up.
@@ -233,6 +245,9 @@ tablet_geom(const ncreel* nr, nctablet* t, int* begx, int* begy,
       *begy = frontiertop - *leny;
     }
   }
+  if(*leny <= 0 || *lenx <= 0){
+    return -1;
+  }
   return 0;
 }
 
@@ -256,7 +271,7 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
 //fprintf(stderr, "no room: %p base %d/%d len %d/%d dir %d\n", t, begy, begx, leny, lenx, direction);
     return -1;
   }
-//fprintf(stderr, "tplacement: %p base %d/%d len %d/%d frontiery %d %d dir %d\n", t, begy, begx, leny, lenx, frontiertop, frontierbottom, direction);
+//fprintf(stderr, "p tplacement: %p base %d/%d len %d/%d frontiery %d %d dir %d\n", t, begy, begx, leny, lenx, frontiertop, frontierbottom, direction);
   ncplane* fp = ncplane_new(nr->p, leny, lenx, begy, begx, NULL, "tab");
   if((t->p = fp) == NULL){
 //fprintf(stderr, "failure creating border plane %d %d %d %d\n", leny, lenx, begy, begx);
@@ -276,9 +291,10 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
     ++cbx;
   }
   if(cbleny - cby + 1 > 0){
-    t->cbp = ncplane_new(t->p, cbleny - cby + 1, cblenx - cbx + 1, cby, cbx, NULL, "tdat");
+//fprintf(stderr, "cbp placement %dx%d @ %dx%d\n", cbleny, cblenx, cby, cbx);
+    t->cbp = ncplane_new(t->p, cbleny, cblenx, cby, cbx, NULL, "tdat");
     if(t->cbp == NULL){
-//fprintf(stderr, "failure creating data plane %d %d %d %d\n", cbleny - cby + 1, cblenx - cbx + 1, cby, cbx);
+//fprintf(stderr, "failure creating data plane %d %d %d %d\n", cbleny, cblenx, cby, cbx);
       ncplane_destroy(t->p);
       t->p = NULL;
       return -1;
@@ -287,6 +303,10 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
 //fprintf(stderr, "calling! lenx/leny: %d/%d cbx/cby: %d/%d cblenx/cbleny: %d/%d dir: %d\n", lenx, leny, cbx, cby, cblenx, cbleny, direction);
     int ll = t->cbfxn(t, direction == DIRECTION_DOWN);
 //fprintf(stderr, "RETURNRETURNRETURN %p %d (%d, %d, %d) DIR %d\n", t, ll, cby, cbleny, leny, direction);
+    if(ll > cbleny){
+      logwarn(nr->p->nc, "Tablet callback returned %d lines, %d allowed\n", ll, cbleny);
+      ll = cbleny;
+    }
     if(ll != cbleny){
       int diff = cbleny - ll;
 //fprintf(stderr, "resizing data plane %d->%d\n", cbleny, leny - diff);
@@ -315,7 +335,8 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
     }
   }
   draw_borders(fp, nr->ropts.tabletmask,
-               nr->tablets == t ? nr->ropts.focusedchan : nr->ropts.tabletchan);
+               nr->tablets == t ? nr->ropts.focusedchan : nr->ropts.tabletchan,
+               direction);
   return 0;
 }
 
@@ -324,9 +345,10 @@ ncreel_draw_tablet(const ncreel* nr, nctablet* t, int frontiertop,
 static nctablet*
 draw_following_tablets(const ncreel* nr, nctablet* otherend,
                        int frontiertop, int* frontierbottom){
+  const bool botborder = !(nr->ropts.bordermask & NCBOXMASK_BOTTOM);
 //fprintf(stderr, "following otherend: %p ->p: %p %d/%d\n", otherend, otherend->p, frontiertop, *frontierbottom);
   nctablet* working = nr->tablets->next;
-  const int maxx = ncplane_dim_y(nr->p) - 1;
+  const int maxx = ncplane_dim_y(nr->p) - 1 - botborder;
   // move down past the focused tablet, filling up the reel to the bottom
   while(*frontierbottom <= maxx && (working != otherend || !otherend->p)){
     if(working->p){
@@ -353,10 +375,11 @@ draw_following_tablets(const ncreel* nr, nctablet* otherend,
 static nctablet*
 draw_previous_tablets(const ncreel* nr, nctablet* otherend,
                       int* frontiertop, int frontierbottom){
+  const bool topborder = !(nr->ropts.bordermask & NCBOXMASK_TOP);
   nctablet* upworking = nr->tablets->prev;
 //fprintf(stderr, "preceding %p otherend: %p ->p: %p frontiers: %d %d\n", upworking, otherend, otherend->p, *frontiertop, frontierbottom);
   // modify frontier based off the one we're at
-  while(*frontiertop >= 0 && (upworking != otherend || !otherend->p)){
+  while(*frontiertop >= topborder && (upworking != otherend || !otherend->p)){
     if(upworking->p){
       break;
     }
@@ -645,6 +668,7 @@ int ncreel_redraw(ncreel* nr){
   if(focused){
 //fprintf(stderr, "drawing focused tablet %p dir: %d fulcrum: %d!\n", focused, nr->direction, fulcrum);
     if(ncreel_draw_tablet(nr, focused, fulcrum, fulcrum, DIRECTION_DOWN)){
+      logerror(nr->p->nc, "Error drawing tablet\n");
       return -1;
     }
 //fprintf(stderr, "drew focused tablet %p -> %p lastdir: %d!\n", focused, focused->p, nr->direction);
@@ -656,21 +680,25 @@ int ncreel_redraw(ncreel* nr){
     if(nr->direction == LASTDIRECTION_DOWN){
       otherend = draw_previous_tablets(nr, otherend, &frontiertop, frontierbottom);
       if(otherend == NULL){
+        logerror(nr->p->nc, "Error drawing higher tablets\n");
         return -1;
       }
       otherend = draw_following_tablets(nr, otherend, frontiertop, &frontierbottom);
     }else{ // DIRECTION_UP
       otherend = draw_previous_tablets(nr, otherend, &frontiertop, frontierbottom);
       if(otherend == NULL){
+        logerror(nr->p->nc, "Error drawing higher tablets\n");
         return -1;
       }
       otherend = draw_following_tablets(nr, otherend, frontiertop, &frontierbottom);
     }
     if(otherend == NULL){
+      logerror(nr->p->nc, "Error drawing following tablets\n");
       return -1;
     }
 //notcurses_debug(nr->p->nc, stderr);
     if(tighten_reel(nr)){
+      logerror(nr->p->nc, "Error tightening reel\n");
       return -1;
     }
 //notcurses_debug(nr->p->nc, stderr);
@@ -678,6 +706,7 @@ int ncreel_redraw(ncreel* nr){
   nr->vft = nr->tablets; // update the visually-focused tablet pointer
 //fprintf(stderr, "DONE ARRANGING\n");
   if(draw_ncreel_borders(nr)){
+    logerror(nr->p->nc, "Error drawing reel borders\n");
     return -1; // enforces specified dimensional minima
   }
   return 0;
@@ -710,10 +739,14 @@ validate_ncreel_opts(ncplane* n, const ncreel_options* ropts){
   return true;
 }
 
-ncplane* nctablet_ncplane(nctablet* t){
+ncplane* nctablet_plane(nctablet* t){
   return t->cbp;
 }
 
+ncplane* nctablet_ncplane(nctablet* t){ // deprecated
+  return nctablet_plane(t);
+}
+
 ncplane* ncreel_plane(ncreel* nr){
   return nr->p;
 }
@@ -811,8 +844,7 @@ int ncreel_del(ncreel* nr, struct nctablet* t){
   return 0;
 }
 
-int ncreel_destroy(ncreel* nreel){
-  int ret = 0;
+void ncreel_destroy(ncreel* nreel){
   if(nreel){
     nctablet* t;
     while( (t = nreel->tablets) ){
@@ -821,7 +853,6 @@ int ncreel_destroy(ncreel* nreel){
     ncplane_destroy(nreel->p);
     free(nreel);
   }
-  return ret;
 }
 
 void* nctablet_userptr(nctablet* t){
