@@ -89,12 +89,25 @@ blocking_write(int fd, const char* buf, size_t buflen){
   return 0;
 }
 
+// update timings for writeout. only call on success.
 static void
-update_render_stats(const struct timespec* time1, const struct timespec* time0,
-                    ncstats* stats, int bytes){
-  int64_t elapsed = timespec_to_ns(time1) - timespec_to_ns(time0);
-  //fprintf(stderr, "Rendering took %ld.%03lds\n", elapsed / NANOSECS_IN_SEC,
-  //        (elapsed % NANOSECS_IN_SEC) / 1000000);
+update_write_stats(const struct timespec* time1, const struct timespec* time0,
+                   ncstats* stats){
+  const int64_t elapsed = timespec_to_ns(time1) - timespec_to_ns(time0);
+  if(elapsed > 0){ // don't count clearly incorrect information, egads
+    stats->writeout_ns += elapsed;
+    if(elapsed > stats->writeout_max_ns){
+      stats->writeout_max_ns = elapsed;
+    }
+    if(elapsed < stats->writeout_min_ns){
+      stats->writeout_min_ns = elapsed;
+    }
+  }
+}
+
+// negative 'bytes' is recorded as a failure.
+static void
+update_render_bytes(ncstats* stats, int bytes){
   if(bytes >= 0){
     stats->render_bytes += bytes;
     if(bytes > stats->render_max_bytes){
@@ -106,6 +119,14 @@ update_render_stats(const struct timespec* time1, const struct timespec* time0,
   }else{
     ++stats->failed_renders;
   }
+}
+
+static void
+update_render_stats(const struct timespec* time1, const struct timespec* time0,
+                    ncstats* stats){
+  const int64_t elapsed = timespec_to_ns(time1) - timespec_to_ns(time0);
+  //fprintf(stderr, "Rendering took %ld.%03lds\n", elapsed / NANOSECS_IN_SEC,
+  //        (elapsed % NANOSECS_IN_SEC) / 1000000);
   if(elapsed > 0){ // don't count clearly incorrect information, egads
     ++stats->renders;
     stats->render_ns += elapsed;
@@ -733,7 +754,6 @@ stage_cursor(notcurses* nc, FILE* out, int y, int x){
 // *become* the last frame rasterized.
 static int
 notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
-  int ret = 0;
   int y, x;
   fseeko(out, 0, SEEK_SET);
   // we only need to emit a coordinate if it was damaged. the damagemap is a
@@ -758,13 +778,17 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
         }
       }else{
         ++nc->stats.cellemissions;
-        ret |= stage_cursor(nc, out, y, x);
+        if(stage_cursor(nc, out, y, x)){
+          return -1;
+        }
         // set the style. this can change the color back to the default; if it
         // does, we need update our elision possibilities.
         bool normalized;
-        ret |= term_setstyles(out, &nc->rstate.curattr, srccell, &normalized,
-                              nc->tcache.sgr0, nc->tcache.sgr,
-                              nc->tcache.italics, nc->tcache.italoff);
+        if(term_setstyles(out, &nc->rstate.curattr, srccell, &normalized,
+                          nc->tcache.sgr0, nc->tcache.sgr,
+                          nc->tcache.italics, nc->tcache.italoff)){
+          return -1;
+        }
         if(normalized){
           nc->rstate.defaultelidable = true;
           nc->rstate.bgelidable = false;
@@ -787,7 +811,9 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
           if(!nc->rstate.defaultelidable){
             ++nc->stats.defaultemissions;
             if(nc->tcache.op){
-              ret |= term_emit("op", nc->tcache.op, out, false);
+              if(term_emit("op", nc->tcache.op, out, false)){
+                return -1;
+              }
             }
           }else{
             ++nc->stats.defaultelisions;
@@ -809,7 +835,9 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
           if(nc->rstate.fgpalelidable && nc->rstate.lastr == palfg){
             ++nc->stats.fgelisions;
           }else{
-            ret |= term_fg_palindex(nc, out, palfg);
+            if(term_fg_palindex(nc, out, palfg)){
+              return -1;
+            }
             ++nc->stats.fgemissions;
             nc->rstate.fgpalelidable = true;
           }
@@ -821,7 +849,9 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
           if(nc->rstate.fgelidable && nc->rstate.lastr == r && nc->rstate.lastg == g && nc->rstate.lastb == b){
             ++nc->stats.fgelisions;
           }else{
-            ret |= term_fg_rgb8(nc->tcache.RGBflag, nc->tcache.setaf, nc->tcache.colors, out, r, g, b);
+            if(term_fg_rgb8(nc->tcache.RGBflag, nc->tcache.setaf, nc->tcache.colors, out, r, g, b)){
+              return -1;
+            }
             ++nc->stats.fgemissions;
             nc->rstate.fgelidable = true;
           }
@@ -836,7 +866,9 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
           if(nc->rstate.bgpalelidable && nc->rstate.lastbr == palbg){
             ++nc->stats.bgelisions;
           }else{
-            ret |= term_bg_palindex(nc, out, palbg);
+            if(term_bg_palindex(nc, out, palbg)){
+              return -1;
+            }
             ++nc->stats.bgemissions;
             nc->rstate.bgpalelidable = true;
           }
@@ -848,7 +880,9 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
           if(nc->rstate.bgelidable && nc->rstate.lastbr == br && nc->rstate.lastbg == bg && nc->rstate.lastbb == bb){
             ++nc->stats.bgelisions;
           }else{
-            ret |= term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab, nc->tcache.colors, out, br, bg, bb);
+            if(term_bg_rgb8(nc->tcache.RGBflag, nc->tcache.setab, nc->tcache.colors, out, br, bg, bb)){
+              return -1;
+            }
             ++nc->stats.bgemissions;
             nc->rstate.bgelidable = true;
           }
@@ -857,26 +891,28 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
           nc->rstate.bgpalelidable = false;
         }
 //fprintf(stderr, "RAST %08x [%s] to %d/%d %016lx\n", srccell->gcluster, pool_extended_gcluster(&nc->pool, srccell), y, x, srccell->channels);
-        if(term_putc(out, &nc->pool, srccell) == 0){
+        if(term_putc(out, &nc->pool, srccell)){
+          return -1;
+        }
+        ++nc->rstate.x;
+        if(cell_wide_left_p(srccell)){
           ++nc->rstate.x;
-          if(cell_wide_left_p(srccell)){
-            ++nc->rstate.x;
-            ++x;
-          }
-          // if the terminal's own motion carried us down to the next line,
-          // we need update our concept of the cursor's true y
-          /*if(nc->rstate.x >= nc->truecols){
-            ++nc->rstate.y; // FIXME not if on last line, right?
-            nc->rstate.x = 0;
-          }*/
-        }else{
-          ret = -1;
+          ++x;
         }
       }
 //fprintf(stderr, "damageidx: %ld\n", damageidx);
     }
   }
-  ret |= fflush(out);
+  return nc->rstate.mstrsize;
+}
+
+// rasterize the rendered frame, and blockingly write it out to the terminal.
+static int
+raster_and_write(notcurses* nc, const struct crender* rvec, FILE* out){
+  if(notcurses_rasterize_inner(nc, rvec, out) < 0){
+    return -1;
+  }
+  int ret = fflush(out);
   //fflush(nc->ttyfp);
   if(blocking_write(fileno(nc->ttyfp), nc->rstate.mstream, nc->rstate.mstrsize)){
     ret = -1;
@@ -893,7 +929,8 @@ notcurses_rasterize_inner(notcurses* nc, const struct crender* rvec, FILE* out){
 
 // if the cursor is enabled, store its location and disable it. then, once done
 // rasterizing, enable it afresh, moving it to the stored location. if left on
-// during rasterization, we'll get grotesque flicker.
+// during rasterization, we'll get grotesque flicker. 'out' is a memstream
+// used to collect a buffer.
 static inline int
 notcurses_rasterize(notcurses* nc, const struct crender* rvec, FILE* out){
   const int cursory = nc->cursory;
@@ -901,7 +938,7 @@ notcurses_rasterize(notcurses* nc, const struct crender* rvec, FILE* out){
   if(cursory >= 0){ // either both are good, or neither is
     notcurses_cursor_disable(nc);
   }
-  int ret = notcurses_rasterize_inner(nc, rvec, out);
+  int ret = raster_and_write(nc, rvec, out);
   if(cursory >= 0){
     notcurses_cursor_enable(nc, cursory, cursorx);
   }
@@ -977,7 +1014,7 @@ int notcurses_render_to_file(notcurses* nc, FILE* fp){
   for(int i = 0 ; i < count ; ++i){
     rvec[i].damaged = true;
   }
-  int ret = notcurses_rasterize_inner(nc, rvec, out);
+  int ret = raster_and_write(nc, rvec, out);
   free(rvec);
   if(ret > 0){
     if(fprintf(fp, "%s", rastered) == ret){
@@ -1012,8 +1049,7 @@ notcurses_render_internal(notcurses* nc, struct crender* rvec){
 }
 
 int notcurses_render(notcurses* nc){
-  struct timespec start, done;
-  int ret;
+  struct timespec start, rasterdone;
   clock_gettime(CLOCK_MONOTONIC, &start);
   int dimy, dimx;
   notcurses_resize(nc, &dimy, &dimx);
@@ -1022,13 +1058,48 @@ int notcurses_render(notcurses* nc){
   struct crender* crender = malloc(crenderlen);
   init_rvec(crender, crenderlen / sizeof(struct crender));
   if(notcurses_render_internal(nc, crender) == 0){
+    clock_gettime(CLOCK_MONOTONIC, &rasterdone);
+    update_render_stats(&rasterdone, &start, &nc->stats);
     bytes = notcurses_rasterize(nc, crender, nc->rstate.mstreamfp);
   }
+  update_render_bytes(&nc->stats, bytes);
   free(crender);
-  clock_gettime(CLOCK_MONOTONIC, &done);
-  update_render_stats(&done, &start, &nc->stats, bytes);
-  ret = bytes >= 0 ? 0 : -1;
-  return ret;
+  if(bytes < 0){
+    return -1;
+  }
+  struct timespec writedone;
+  clock_gettime(CLOCK_MONOTONIC, &writedone);
+  update_write_stats(&writedone, &rasterdone, &nc->stats);
+  return 0;
+}
+
+// for now, we just run the top half of notcurses_render(), and copy out the
+// memstream from within rstate. we want to allocate our own here, and return
+// it, to avoid the copy, but we need feed the params through to do so FIXME.
+int notcurses_render_to_buffer(notcurses* nc, char** buf, size_t* buflen){
+  struct timespec start, rasterdone;
+  clock_gettime(CLOCK_MONOTONIC, &start);
+  int dimy, dimx;
+  notcurses_resize(nc, &dimy, &dimx);
+  int bytes = -1;
+  const size_t crenderlen = sizeof(struct crender) * nc->stdplane->leny * nc->stdplane->lenx;
+  struct crender* crender = malloc(crenderlen);
+  init_rvec(crender, crenderlen / sizeof(struct crender));
+  if(notcurses_render_internal(nc, crender) == 0){
+    clock_gettime(CLOCK_MONOTONIC, &rasterdone);
+    update_render_stats(&rasterdone, &start, &nc->stats);
+    bytes = notcurses_rasterize_inner(nc, crender, nc->rstate.mstreamfp);
+  }
+  update_render_bytes(&nc->stats, bytes);
+  if(bytes < 0){
+    return -1;
+  }
+  *buf = memdup(nc->rstate.mstreamfp, nc->rstate.mstrsize);
+  if(buf == NULL){
+    return -1;
+  }
+  *buflen = nc->rstate.mstrsize;
+  return 0;
 }
 
 // copy the UTF8-encoded EGC out of the cell, whether simple or complex. the
